
from Globals import *
import gobject
import gtk
import gtk.glade

class NewUserAccountDialog(gobject.GObject):

    __gsignals__ = {
        'account-created' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
                                (gobject.TYPE_PYOBJECT, ))
        }

    def __init__(self, container):
        gobject.GObject.__init__(self)
        self.container = container

        self.gxml = gtk.glade.XML(GLADE_FILE, 'newUserDialog')
        self.dlg = self.gxml.get_widget('newUserDialog')
        self.errorMessage = self.gxml.get_widget('errorMessage')

        self.primaryGroup = None
        # Connect the glade signals
        function_dict = dict([(f, getattr(self, f)) for f in dir(self)]) 
        self.gxml.signal_autoconnect(function_dict)

        iconTheme = gtk.IconTheme()
        self.grouppb = images['stock_contact_list']

    def SetErrorMessage(self, message):
        errorTemplate = '<span color="red"><b>%s</b></span>'
        self.errorMessage.set_text(errorTemplate % (message))
        self.errorMessage.set_use_markup(True)
        self.errorMessage.show()

    def OnOkClicked(self, obj, *args):

        if not (self.primaryGroup):
            return

        self.dlg.hide()

        uid = self.gxml.get_widget('uid').get_text()
        givenName = self.gxml.get_widget('givenName').get_text()
        initials = self.gxml.get_widget('initials').get_text()
        sn = self.gxml.get_widget('sn').get_text()
        displayName = self.gxml.get_widget('displayName').get_text()
        cn = displayName
        description = self.gxml.get_widget('description').get_text()
       
        try:
            self.container.CreateUser(uid, 
                        self.primaryGroup,
                        givenName, sn, initials, cn, displayName,
                        description)
            self.emit('account-created', self.container)
            self.dlg.destroy()        
        except Exception, err:
            #FIXME: popup an error dialog
            self.SetErrorMessage(err)
            self.gxml.get_widget('uid').grab_focus()
            self.dlg.show()
            print "error creating user account: %s" % (err)

    def OnCancelClicked(self, obj, *args):
        self.dlg.destroy()

    def OnPrimaryGroupButtonClicked(self, obj, *args):
        gxml = gtk.glade.XML(GLADE_FILE, 'memberOf_AddGroup')
        dlg = gxml.get_widget('memberOf_AddGroup')

        treeview = gxml.get_widget('treeview2')
        listModel = gtk.ListStore(gtk.gdk.Pixbuf, str, str, object)
        cellpb = gtk.CellRendererPixbuf()
        cellpb.set_property('xalign', 0.0)
        celltext = gtk.CellRendererText()
        col1 = gtk.TreeViewColumn('Name', cellpb, pixbuf=0)
        col1.pack_start(celltext, False)
        col1.add_attribute(celltext, 'text', 1)
        celltext = gtk.CellRendererText()
        col2 = gtk.TreeViewColumn('Path', celltext, text=2)
        treeview.append_column(col1)
        treeview.append_column(col2)
       
        groups = self.container.dsconn.Groups()
        for group in groups:
            listModel.append((self.grouppb, group.Name(),
                    group.PrettyPath(), group))
        treeview.set_model(listModel)
        res = dlg.run()
        dlg.hide()
        if (res == gtk.RESPONSE_OK):
            selection = treeview.get_selection()
            model, iter = selection.get_selected()
            self.primaryGroup = model.get_value(iter, 3)
            cn = self.primaryGroup.Name()
            self.gxml.get_widget('primaryGroup').set_text(cn)
            if (self.gxml.get_widget('uid').get_text()):
                self.gxml.get_widget('okbutton4').set_sensitive(True)
        dlg.destroy()

    def OnUidChanged(self, UidEntry):
        if not (self.primaryGroup):
            return
        elif (UidEntry.get_text()):
            self.gxml.get_widget('okbutton4').set_sensitive(True)
        else:
            self.gxml.get_widget('okbutton4').set_sensitive(False)
        
    def OnDeleteEvent(self, obj, *args):
        return False

gobject.type_register(NewUserAccountDialog)
